@@ -670,13 +670,12 @@ class Migration:
         print(f'Using migration {cls.id}', end='')
 
         try:
-            await connection.execute('\n'.join(commands_query))
+            await connection.execute(';\n'.join(commands_query))
             print(' [OK]')
         except Exception as exception:
             print(' [ERROR]\n')
             raise exception
 
-
     @staticmethod
     def get_constructor(commands):
         commands_lines = []
